@@ -25,7 +25,7 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 
 __all__ = ['IMDb', 'IMDbError', 'Movie', 'Person', 'Character', 'Company',
            'available_access_systems']
-__version__ = VERSION = '6.7'
+__version__ = VERSION = '6.8'
 
 
 import logging
@@ -299,6 +299,8 @@ class IMDbBase:
         imdbURL_bottom100 = imdbURL_base + 'chart/bottom'
         # http://www.imdb.com/find?%s
         imdbURL_find = imdbURL_base + 'find?%s'
+        # http://www.imdb.com/search/title?%s
+        imdbURL_search_movie_advanced = imdbURL_base + 'search/title/?%s'
         self.urls = dict(
             movie_base=imdbURL_movie_base,
             movie_main=imdbURL_movie_main,
@@ -311,7 +313,8 @@ class IMDbBase:
             keyword_main=imdbURL_keyword_main,
             top250=imdbURL_top250,
             bottom100=imdbURL_bottom100,
-            find=imdbURL_find)
+            find=imdbURL_find,
+            search_movie_advanced=imdbURL_search_movie_advanced)
 
     def _normalize_movieID(self, movieID):
         """Normalize the given movieID."""
@@ -426,6 +429,26 @@ class IMDbBase:
                 data=md, modFunct=self._defModFunct,
                 accessSystem=self.accessSystem) for mi, md in res][:results]
 
+    def _search_movie_advanced(self, title=None, adult=None, results=None, sort=None, sort_dir=None):
+        """Return a list of tuples (movieID, {movieData})"""
+        # XXX: for the real implementation, see the method of the
+        #      subclass, somewhere under the imdb.parser package.
+        raise NotImplementedError('override this method')
+
+    def search_movie_advanced(self, title=None, adult=None, results=None, sort=None, sort_dir=None):
+        """Return a list of Movie objects for a query for the given title.
+        The results argument is the maximum number of results to return."""
+        if results is None:
+            results = self._results
+        try:
+            results = int(results)
+        except (ValueError, OverflowError):
+            results = 20
+        res = self._search_movie_advanced(title=title, adult=adult, results=results, sort=sort, sort_dir=sort_dir)
+        return [Movie.Movie(movieID=self._get_real_movieID(mi),
+                data=md, modFunct=self._defModFunct,
+                accessSystem=self.accessSystem) for mi, md in res][:results]
+
     def _search_episode(self, title, results):
         """Return a list of tuples (movieID, {movieData})"""
         # XXX: for the real implementation, see the method of the
@@ -858,13 +881,13 @@ class IMDbBase:
             if mop.personID is not None:
                 imdbID = aSystem.get_imdbPersonID(mop.personID)
             else:
-                imdbID = aSystem.name2imdbID(build_name(mop, canonical=1))
+                imdbID = aSystem.name2imdbID(build_name(mop, canonical=False))
         elif isinstance(mop, Character.Character):
             if mop.characterID is not None:
                 imdbID = aSystem.get_imdbCharacterID(mop.characterID)
             else:
                 # canonical=0 ?
-                imdbID = aSystem.character2imdbID(build_name(mop, canonical=1))
+                imdbID = aSystem.character2imdbID(build_name(mop, canonical=False))
         elif isinstance(mop, Company.Company):
             if mop.companyID is not None:
                 imdbID = aSystem.get_imdbCompanyID(mop.companyID)
