@@ -384,6 +384,25 @@ class DOMHTMLMovieParser(DOMParserBase):
                 transform=lambda x: x.replace(' (', '::(')
             )
         ),
+        Rule(
+            key='box office',
+            extractor=Rules(
+                foreach='//section[contains(@class, "titlereference-section-box-office")]'
+                        '//table[contains(@class, "titlereference-list")]//tr',
+                rules=[
+                    Rule(
+                        key='box_office_title',
+                        extractor=Path('./td[1]/text()')
+                    ),
+                    Rule(
+                        key='box_office_detail',
+                        extractor=Path('./td[2]/text()')
+                    )
+                ],
+                transform=lambda x: (x['box_office_title'].strip(),
+                                     x['box_office_detail'].strip())
+            ),
+        ),
         Rule(
             key='certificates',
             extractor=Path(
@@ -762,6 +781,8 @@ class DOMHTMLMovieParser(DOMParserBase):
                         key = '%s companies' % key
                     data.update({key: value})
             del data['companies']
+        if 'box office' in data:
+            data['box office'] = dict(data['box office'])
         return data
 
 
@@ -1676,12 +1697,17 @@ class DOMHTMLFullCreditsParser(DOMParserBase):
                     Rule(
                         key='roleID',
                         extractor=Path('./td[4]//div[@class="_imdbpyrole"]/@roleid')
+                    ),
+                    Rule(
+                        key='headshot',
+                        extractor=Path('./td[@class="primary_photo"]/a/img/@loadlate')
                     )
                 ],
                 transform=lambda x: build_person(
-                    x.get('person') or '',
+                    x.get('person', ''),
                     personID=analyze_imdbid(x.get('link')),
-                    roleID=(x.get('roleID') or '').split('/')
+                    roleID=(x.get('roleID', '')).split('/'),
+                    headshot=(x.get('headshot', ''))
                 )
             )
         )
@@ -1691,6 +1717,15 @@ class DOMHTMLFullCreditsParser(DOMParserBase):
         (_reRolesMovie, _manageRoles)
     ]
 
+    def postprocess_data(self, data):
+        clean_cast = []
+        for person in data.get('cast', []):
+            if person.personID and person.get('name'):
+                clean_cast.append(person)
+        if clean_cast:
+            data['cast'] = clean_cast
+        return data
+
 
 class DOMHTMLOfficialsitesParser(DOMParserBase):
     """Parser for the "official sites", "external reviews"
@@ -2508,19 +2543,18 @@ class DOMHTMLParentsGuideParser(DOMParserBase):
         Rule(
             key='parents guide',
             extractor=Rules(
-                foreach='//div[@class="section"]',
+                foreach='//tr[@class="ipl-zebra-list__item"]',
                 rules=[
                     Rule(
                         key=Path(
-                            './h3/a/span/text()',
+                            './td[1]/text()',
                             transform=transformers.lower
                         ),
                         extractor=Path(
-                            foreach='../following-sibling::div[1]/p',
-                            path='.//text()',
+                            path='./td[2]//text()',
                             transform=lambda x: [
-                                t.strip().replace('\n', ' ')
-                                for t in x.split('||') if t.strip()
+                                re_space.sub(' ', t)
+                                for t in x.split('\n') if t.strip()
                             ]
                         )
                     )
@@ -2529,18 +2563,14 @@ class DOMHTMLParentsGuideParser(DOMParserBase):
         )
     ]
 
-    preprocessors = [
-        (re.compile('<br/><br/>', re.I), r'||')
-    ]
-
     def postprocess_data(self, data):
-        data2 = {}
-        for key in data:
-            if data[key]:
-                data2[key] = data[key]
-        if not data2:
-            return {}
-        return {'parents guide': data2}
+        ret = {}
+        for sect in data.get('parents guide', []):
+            for key, value in sect.items():
+                ret[key] = value
+        if isinstance(ret.get('mpaa'), list):
+            ret['mpaa'] = ret['mpaa'][0]
+        return ret
 
 
 _OBJECTS = {
