@@ -22,7 +22,6 @@ in the :mod:`imdb.parser.http` package.
 
 from __future__ import absolute_import, division, print_function, unicode_literals
 
-import collections
 import logging
 import re
 
@@ -37,6 +36,12 @@ from .piculet import xpath as piculet_xpath
 from .piculet import Rule, Path
 
 
+if PY2:
+    from collections import Callable
+else:
+    from collections.abc import Callable
+
+
 # Year, imdbIndex and kind.
 re_yearKind_index = re.compile(
     r'(\([0-9\?]{4}(?:/[IVXLCDM]+)?\)(?: \(mini\)| \(TV\)| \(V\)| \(VG\))?)'
@@ -89,7 +94,7 @@ _b_p_logger = logging.getLogger('imdbpy.parser.http.build_person')
 
 
 def build_person(txt, personID=None, billingPos=None,
-                 roleID=None, accessSystem='http', modFunct=None):
+                 roleID=None, accessSystem='http', modFunct=None, headshot=None):
     """Return a Person instance from the tipical <tr>...</tr> strings
     found in the IMDb's web site."""
     # if personID is None
@@ -187,9 +192,12 @@ def build_person(txt, personID=None, billingPos=None,
         else:
             notes = notes.strip()
     # XXX: return None if something strange is detected?
+    data = {}
+    if headshot:
+        data['headshot'] = headshot
     person = Person(name=name, personID=personID, currentRole=role,
                     roleID=roleID, notes=notes, billingPos=billingPos,
-                    modFunct=modFunct, accessSystem=accessSystem)
+                    modFunct=modFunct, accessSystem=accessSystem, data=data)
     if roleNotes and len(roleNotes) == len(roleID):
         for idx, role in enumerate(person.currentRole):
             if roleNotes[idx]:
@@ -488,11 +496,11 @@ class DOMParserBase(object):
             return html_string
         for src, sub in preprocessors:
             # re._pattern_type is present only since Python 2.5.
-            if isinstance(getattr(src, 'sub', None), collections.Callable):
+            if isinstance(getattr(src, 'sub', None), Callable):
                 html_string = src.sub(sub, html_string)
             elif isinstance(src, str) or isinstance(src, unicode):
                 html_string = html_string.replace(src, sub)
-            elif isinstance(src, collections.Callable):
+            elif isinstance(src, Callable):
                 try:
                     html_string = src(html_string)
                 except Exception:
