@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2017-2018 Davide Alberani <da@erlug.linux.it>
+# Copyright 2017-2019 Davide Alberani <da@erlug.linux.it>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -255,6 +255,9 @@ class IMDbS3AccessSystem(IMDbBase):
         results = [x[1] for x in results]
         return results
 
+    def _search_movie_advanced(self, title=None, adult=None, results=None, sort=None, sort_dir=None):
+        return self._search_movie(title, results)
+
     def _search_episode(self, title, results):
         return self._search_movie(title, results=results, _episodes=True)
 
